# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import EntitlementsUpdatedPayload


class EntitlementsUpdated(BaseModel):
    entitlements_updated: "EntitlementsUpdatedEntitlementsUpdated" = Field(
        alias="entitlementsUpdated"
    )


class EntitlementsUpdatedEntitlementsUpdated(EntitlementsUpdatedPayload):
    pass


EntitlementsUpdated.update_forward_refs()
EntitlementsUpdatedEntitlementsUpdated.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class InitiateCheckout(BaseModel):
    initiate_checkout: "InitiateCheckoutInitiateCheckout" = Field(
        alias="initiateCheckout"
    )


class InitiateCheckoutInitiateCheckout(BaseModel):
    checkout_url: str = Field(alias="checkoutUrl")
    checkout_billing_id: str = Field(alias="checkoutBillingId")


InitiateCheckout.update_forward_refs()
InitiateCheckoutInitiateCheckout.update_forward_refs()



from stigg.generated import Client


class StiggClient(Client):
    pass


class Stigg:
    @staticmethod
    def create_async_client(
            api_key: str, api_url: str = "https://api.stigg.io/graphql"
    ) -> StiggClient:
        headers = {"X-API-KEY": api_key, "Content-Type": "application/json"}
        return StiggClient(url=api_url, headers=headers)



# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetSdkConfiguration(BaseModel):
    sdk_configuration: Optional["GetSdkConfigurationSdkConfiguration"] = Field(
        alias="sdkConfiguration"
    )


class GetSdkConfigurationSdkConfiguration(BaseModel):
    sentry_dsn: Optional[str] = Field(alias="sentryDsn")
    is_widget_watermark_enabled: Optional[bool] = Field(
        alias="isWidgetWatermarkEnabled"
    )


GetSdkConfiguration.update_forward_refs()
GetSdkConfigurationSdkConfiguration.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import CustomerWithSubscriptionsFragment


class GetCustomerById(BaseModel):
    get_customer_by_ref_id: Optional["GetCustomerByIdGetCustomerByRefId"] = Field(
        alias="getCustomerByRefId"
    )


class GetCustomerByIdGetCustomerByRefId(CustomerWithSubscriptionsFragment):
    pass


GetCustomerById.update_forward_refs()
GetCustomerByIdGetCustomerByRefId.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import EntitlementUsageUpdated


class UsageUpdated(BaseModel):
    usage_updated: "UsageUpdatedUsageUpdated" = Field(alias="usageUpdated")


class UsageUpdatedUsageUpdated(EntitlementUsageUpdated):
    pass


UsageUpdated.update_forward_refs()
UsageUpdatedUsageUpdated.update_forward_refs()
